# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x62i/mde_objects.proto\x12\x0e\x62i.mde_objects\"\x8e\x02\n\x0bGBMBIObject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x62iObjectType\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x13\n\x0blastUpdated\x18\x06 \x01(\t\x12\x12\n\nsource_url\x18\x07 \x01(\t\x12G\n\x0e\x62iCompositeKey\x18\x08 \x03(\x0b\x32/.bi.mde_objects.GBMBIObject.BiCompositeKeyEntry\x1a\x35\n\x13\x42iCompositeKeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\tGBMBIUser\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x10\n\x08username\x18\x02 \x01(\t\"\xa9\x01\n\x0bGBMBIFolder\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x12\n\nnumReports\x18\x03 \x01(\x05\x12\x19\n\x11numReportAccesses\x18\x04 \x01(\x05\x12\x16\n\x0eparentFolderId\x18\x05 \x01(\t\x12\x15\n\risExtractable\x18\x06 \x01(\x08\"\xfb\x01\n\x0bGBMBIReport\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x13\n\x0bnumAccesses\x18\x03 \x01(\x05\x12\x16\n\x0eparentFolderId\x18\x04 \x01(\t\x12\x17\n\x0fparentReportIds\x18\x05 \x03(\t\x12\x15\n\rdatasourceIds\x18\x06 \x03(\t\x12.\n\x04type\x18\x07 \x01(\x0e\x32 .bi.mde_objects.GBMBIReport.Type\"!\n\x04Type\x12\n\n\x06SIMPLE\x10\x00\x12\r\n\tDASHBOARD\x10\x01\"\x9b\x01\n\x0fGBMBIDatasource\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x16\n\x0eparentFolderId\x18\x03 \x01(\t\x12\x15\n\rconnectionIds\x18\x04 \x03(\t\x12\x1b\n\x13linkedDatasourceIds\x18\x05 \x03(\t\"\xe2\x02\n\x0fGBMBIConnection\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x16\n\x0eparentFolderId\x18\x02 \x01(\t\x12<\n\x0e\x63onnectionType\x18\x03 \x01(\x0e\x32$.bi.mde_objects.GBMBIConnection.Type\x12\x1d\n\x15\x64isplayConnectionType\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x05 \x01(\t\x12\x0c\n\x04host\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x07 \x01(\t\x12\x10\n\x08\x64\x62Schema\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x62Table\x18\t \x01(\t\x12\x0b\n\x03sql\x18\n \x01(\t\x12\x11\n\tdataFiles\x18\x0b \x03(\t\"6\n\x04Type\x12\t\n\x05\x46ILES\x10\x00\x12\t\n\x05TABLE\x10\x01\x12\r\n\tSQL_QUERY\x10\x02\x12\t\n\x05OTHER\x10\x03\"\x84\x01\n\x0fGBMBIColumnBase\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x10\n\x08\x64\x61taType\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x0e\n\x06values\x18\x05 \x03(\t\"\x98\x01\n\x11GBMBIReportColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x10\n\x08reportId\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x61tasourceColumnIds\x18\x03 \x03(\t\x12\x1d\n\x15parentReportColumnIds\x18\x04 \x03(\t\"\xaa\x01\n\x15GBMBIDatasourceColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x14\n\x0c\x64\x61tasourceId\x18\x02 \x01(\t\x12!\n\x19parentDatasourceColumnIds\x18\x03 \x03(\t\x12!\n\x19parentConnectionColumnIds\x18\x04 \x03(\t\"d\n\x15GBMBIConnectionColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x14\n\x0c\x63onnectionId\x18\x02 \x01(\t\"d\n\x0fGBMBIPermission\x12\x16\n\x0euserExternalId\x18\x01 \x01(\t\x12\x13\n\x0bobjectOType\x18\x02 \x01(\t\x12\x18\n\x10objectExternalId\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"Y\n\nGBMBIImage\x12\x11\n\timageName\x18\x01 \x01(\t\x12\x11\n\timageData\x18\x02 \x01(\x0c\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x0f\n\x07hasMore\x18\x04 \x01(\x08\"\x1f\n\x0b\x41lationUser\x12\x10\n\x08username\x18\x01 \x01(\tB,\n\x17\x61lation.sdk.bi.grpc.mdeB\x0fMetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.bi.grpc.mdeB\017MetadataObjectsP\001'
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._options = None
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_options = b'8\001'
  _globals['_GBMBIOBJECT']._serialized_start=41
  _globals['_GBMBIOBJECT']._serialized_end=311
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_start=258
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_end=311
  _globals['_GBMBIUSER']._serialized_start=313
  _globals['_GBMBIUSER']._serialized_end=389
  _globals['_GBMBIFOLDER']._serialized_start=392
  _globals['_GBMBIFOLDER']._serialized_end=561
  _globals['_GBMBIREPORT']._serialized_start=564
  _globals['_GBMBIREPORT']._serialized_end=815
  _globals['_GBMBIREPORT_TYPE']._serialized_start=782
  _globals['_GBMBIREPORT_TYPE']._serialized_end=815
  _globals['_GBMBIDATASOURCE']._serialized_start=818
  _globals['_GBMBIDATASOURCE']._serialized_end=973
  _globals['_GBMBICONNECTION']._serialized_start=976
  _globals['_GBMBICONNECTION']._serialized_end=1330
  _globals['_GBMBICONNECTION_TYPE']._serialized_start=1276
  _globals['_GBMBICONNECTION_TYPE']._serialized_end=1330
  _globals['_GBMBICOLUMNBASE']._serialized_start=1333
  _globals['_GBMBICOLUMNBASE']._serialized_end=1465
  _globals['_GBMBIREPORTCOLUMN']._serialized_start=1468
  _globals['_GBMBIREPORTCOLUMN']._serialized_end=1620
  _globals['_GBMBIDATASOURCECOLUMN']._serialized_start=1623
  _globals['_GBMBIDATASOURCECOLUMN']._serialized_end=1793
  _globals['_GBMBICONNECTIONCOLUMN']._serialized_start=1795
  _globals['_GBMBICONNECTIONCOLUMN']._serialized_end=1895
  _globals['_GBMBIPERMISSION']._serialized_start=1897
  _globals['_GBMBIPERMISSION']._serialized_end=1997
  _globals['_GBMBIIMAGE']._serialized_start=1999
  _globals['_GBMBIIMAGE']._serialized_end=2088
  _globals['_ALATIONUSER']._serialized_start=2090
  _globals['_ALATIONUSER']._serialized_end=2121
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VolumeCheckRequest(_message.Message):
    __slots__ = ("configuration", "rootInfo", "is_include_filter")
    class RootInfoEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: RootInfo
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[RootInfo, _Mapping]] = ...) -> None: ...
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    ROOTINFO_FIELD_NUMBER: _ClassVar[int]
    IS_INCLUDE_FILTER_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    rootInfo: _containers.MessageMap[str, RootInfo]
    is_include_filter: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., rootInfo: _Optional[_Mapping[str, RootInfo]] = ..., is_include_filter: bool = ...) -> None: ...

class RootInfo(_message.Message):
    __slots__ = ("tsSnapshot", "currentVolume")
    TSSNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    CURRENTVOLUME_FIELD_NUMBER: _ClassVar[int]
    tsSnapshot: int
    currentVolume: int
    def __init__(self, tsSnapshot: _Optional[int] = ..., currentVolume: _Optional[int] = ...) -> None: ...

class VolumeCheckResponse(_message.Message):
    __slots__ = ("item", "error")
    ITEM_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    item: ResponseItem
    error: _job_error_pb2.Error
    def __init__(self, item: _Optional[_Union[ResponseItem, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...

class ResponseItem(_message.Message):
    __slots__ = ("rootName", "volume", "tsSnapshot")
    ROOTNAME_FIELD_NUMBER: _ClassVar[int]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    TSSNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    rootName: str
    volume: Volume
    tsSnapshot: int
    def __init__(self, rootName: _Optional[str] = ..., volume: _Optional[_Union[Volume, _Mapping]] = ..., tsSnapshot: _Optional[int] = ...) -> None: ...

class Volume(_message.Message):
    __slots__ = ("fileCount", "directoryCount")
    FILECOUNT_FIELD_NUMBER: _ClassVar[int]
    DIRECTORYCOUNT_FIELD_NUMBER: _ClassVar[int]
    fileCount: int
    directoryCount: int
    def __init__(self, fileCount: _Optional[int] = ..., directoryCount: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/configuration_verifycation.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&asset/configuration_verifycation.proto\x12$ocf.asset.configuration_verification\x1a\x13\x63ommon/verify.proto\x1a\x1bgoogle/protobuf/empty.proto2c\n\x19\x43onfigurationVerification\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x42W\n1alation.sdk.asset.grpc.configuration_verificationP\x01Z asset/configuration_verificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.configuration_verifycation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1alation.sdk.asset.grpc.configuration_verificationP\001Z asset/configuration_verification'
  _globals['_CONFIGURATIONVERIFICATION']._serialized_start=130
  _globals['_CONFIGURATIONVERIFICATION']._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from policy import policy_objects_pb2 as policy_dot_policy__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19policy/policy_rdbms.proto\x12\x10ocf.policy.rdbms\x1a\x1a\x63ommon/configuration.proto\x1a\x1bpolicy/policy_objects.proto\x1a\x0frdbms/mde.proto\"\x9f\x01\n\x17PolicyExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\"\xe3\x01\n\x18PolicyExtractionResponse\x12\x33\n\x06policy\x18\x01 \x01(\x0b\x32!.ocf.policy.policy_objects.PolicyH\x00\x12\x39\n\ttableLink\x18\x02 \x01(\x0b\x32$.ocf.policy.policy_objects.TableLinkH\x00\x12;\n\ncolumnLink\x18\x03 \x01(\x0b\x32%.ocf.policy.policy_objects.ColumnLinkH\x00\x42\x1a\n\x18PolicyExtractionResponse2\x7f\n\x0eRdbmsPolicyMDE\x12m\n\x10PolicyExtraction\x12).ocf.policy.rdbms.PolicyExtractionRequest\x1a*.ocf.policy.rdbms.PolicyExtractionResponse\"\x00\x30\x01\x42\x33\n\x1b\x61lation.sdk.ocf.policy.grpcB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.policy.grpcB\022MetadataExtractionP\001'
  _globals['_POLICYEXTRACTIONREQUEST']._serialized_start=122
  _globals['_POLICYEXTRACTIONREQUEST']._serialized_end=281
  _globals['_POLICYEXTRACTIONRESPONSE']._serialized_start=284
  _globals['_POLICYEXTRACTIONRESPONSE']._serialized_end=511
  _globals['_RDBMSPOLICYMDE']._serialized_start=513
  _globals['_RDBMSPOLICYMDE']._serialized_end=640
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cf import cf_objects_pb2 as cf_dot_cf__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x66/cf_rdbms.proto\x12\x0cocf.cf.rdbms\x1a\x13\x63\x66/cf_objects.proto\x1a\x0frdbms/mde.proto\x1a\x1a\x63ommon/configuration.proto\"\xa4\x01\n\x1c\x43ustomFieldExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\"\xa5\x01\n\x1d\x43ustomFieldExtractionResponse\x12/\n\x05\x66ield\x18\x01 \x01(\x0b\x32\x1e.ocf.cf.cf_objects.CustomFieldH\x00\x12\x32\n\x04link\x18\x02 \x01(\x0b\x32\".ocf.cf.cf_objects.CustomFieldLinkH\x00\x42\x1f\n\x1d\x43ustomFieldExtractionResponse2\x8b\x01\n\x13RdbmsCustomFieldMDE\x12t\n\x15\x43ustomFieldExtraction\x12*.ocf.cf.rdbms.CustomFieldExtractionRequest\x1a+.ocf.cf.rdbms.CustomFieldExtractionResponse\"\x00\x30\x01\x42/\n\x17\x61lation.sdk.ocf.cf.grpcB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.cf.grpcB\022MetadataExtractionP\001'
  _globals['_CUSTOMFIELDEXTRACTIONREQUEST']._serialized_start=102
  _globals['_CUSTOMFIELDEXTRACTIONREQUEST']._serialized_end=266
  _globals['_CUSTOMFIELDEXTRACTIONRESPONSE']._serialized_start=269
  _globals['_CUSTOMFIELDEXTRACTIONRESPONSE']._serialized_end=434
  _globals['_RDBMSCUSTOMFIELDMDE']._serialized_start=437
  _globals['_RDBMSCUSTOMFIELDMDE']._serialized_end=576
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from queryservice_client.protobuf.common import verify_pb2 as _verify_pb2
from fs import mde_pb2 as _mde_pb2
from fs import fs_profiling_pb2 as _fs_profiling_pb2
from fs import volume_check_pb2 as _volume_check_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from asset import mde_objects_pb2 as asset_dot_mde__objects__pb2
from asset import filter_extraction_pb2 as asset_dot_filter__extraction__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61sset/mde.proto\x12\rocf.asset.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\x1a\x17\x61sset/mde_objects.proto\x1a\x1d\x61sset/filter_extraction.proto\x1a\x1f\x63ommon/extraction_objects.proto\"\xb3\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x45\n\x06\x66ilter\x18\x02 \x03(\x0b\x32\x35.ocf.asset.filter_extraction.FilterExtractionResponse\x12\x19\n\x11isInclusionFilter\x18\x03 \x01(\x08\"\x81\x02\n\x1aMetadataExtractionResponse\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.AssetH\x00\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x12?\n\x0e\x64qRuleAndValue\x18\x04 \x01(\x0b\x32%.ocf.asset.mde_objects.DQRuleAndValueH\x00\x42\n\n\x08response2\x83\x01\n\x12MetadataExtraction\x12m\n\x12MetadataExtraction\x12(.ocf.asset.mde.MetadataExtractionRequest\x1a).ocf.asset.mde.MetadataExtractionResponse\"\x00\x30\x01\x42)\n\x1a\x61lation.sdk.asset.grpc.mdeP\x01Z\tasset/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.asset.grpc.mdeP\001Z\tasset/mde'
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=176
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=355
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=358
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=615
  _globals['_METADATAEXTRACTION']._serialized_start=618
  _globals['_METADATAEXTRACTION']._serialized_end=749
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/checks.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/checks.proto\x12\x06\x63hecks\x1a\x1a\x63ommon/configuration.proto\"|\n\x0c\x43heckRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x12\n\ncheck_name\x18\x02 \x01(\t\x12\"\n\tcheck_ids\x18\x03 \x03(\x0b\x32\x0f.checks.CheckID\"\x15\n\x07\x43heckID\x12\n\n\x02id\x18\x01 \x01(\t\"\x88\x01\n\x0b\x43heckResult\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x06result\x18\x02 \x01(\x0e\x32\x13.checks.CheckStatus\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x12.checks.CheckError\x12%\n\x07message\x18\x04 \x01(\x0b\x32\x14.checks.CheckMessage\"D\n\nCheckError\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x12\n\nerror_text\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\",\n\x0c\x43heckMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t*A\n\x0b\x43heckStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07SKIPPED\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x42\x39\n\x1e\x61lation.sdk.grpc.common.checksB\x06\x43hecksP\x01Z\rcommon/checksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.checks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036alation.sdk.grpc.common.checksB\006ChecksP\001Z\rcommon/checks'
  _globals['_CHECKSTATUS']._serialized_start=463
  _globals['_CHECKSTATUS']._serialized_end=528
  _globals['_CHECKREQUEST']._serialized_start=59
  _globals['_CHECKREQUEST']._serialized_end=183
  _globals['_CHECKID']._serialized_start=185
  _globals['_CHECKID']._serialized_end=206
  _globals['_CHECKRESULT']._serialized_start=209
  _globals['_CHECKRESULT']._serialized_end=345
  _globals['_CHECKERROR']._serialized_start=347
  _globals['_CHECKERROR']._serialized_end=415
  _globals['_CHECKMESSAGE']._serialized_start=417
  _globals['_CHECKMESSAGE']._serialized_end=461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17rdbms/mde_objects.proto\x12\x11rdbms.mde_objects\",\n\x04Name\x12\x10\n\x08original\x18\x01 \x01(\t\x12\x12\n\nnormalized\x18\x02 \x01(\t\":\n\x11\x44\x61tabaseCatalogId\x12%\n\x04name\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"c\n\x08SchemaId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\x8b\x01\n\x07TableId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\xb4\x01\n\x08\x43olumnId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12&\n\x05table\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x04 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\x8e\x01\n\nFunctionId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"Z\n\x0f\x44\x61tabaseCatalog\x12\x30\n\x02id\x18\x01 \x01(\x0b\x32$.rdbms.mde_objects.DatabaseCatalogId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\"[\n\x06Schema\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12\x11\n\tisDeleted\x18\x03 \x01(\x08\"\x8e\x01\n\tTableType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\nnormalized\x18\x03 \x01(\x0e\x32+.rdbms.mde_objects.TableType.NormalizedType\"2\n\x0eNormalizedType\x12\t\n\x05TABLE\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0b\n\x07SYNONYM\x10\x03\"M\n\tPartition\x12\x12\n\ndefinition\x18\x01 \x01(\t\x12,\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\"\n\x0e\x46ileSystemPath\x12\x10\n\x08segments\x18\x01 \x03(\t\"s\n\x0c\x44\x61taLocation\x12\x10\n\x08original\x18\x01 \x01(\t\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12\x10\n\x08hostport\x18\x03 \x01(\t\x12/\n\x04path\x18\x04 \x01(\x0b\x32!.rdbms.mde_objects.FileSystemPath\"\xc7\x03\n\x05Table\x12&\n\x02id\x18\x01 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12*\n\x04type\x18\x03 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\x12\x0b\n\x03\x64\x64l\x18\x04 \x01(\t\x12/\n\tpartition\x18\x05 \x01(\x0b\x32\x1c.rdbms.mde_objects.Partition\x12-\n\tbaseTable\x18\x06 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x35\n\x0c\x64\x61taLocation\x18\x08 \x01(\x0b\x32\x1f.rdbms.mde_objects.DataLocation\x12P\n\x14\x61\x64\x64itionalProperties\x18\t \x03(\x0b\x32\x32.rdbms.mde_objects.Table.AdditionalPropertiesEntry\x12\x11\n\tisDeleted\x18\n \x01(\x08\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xda\x01\n\nColumnType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12@\n\nnormalized\x18\x03 \x01(\x0e\x32,.rdbms.mde_objects.ColumnType.NormalizedType\"h\n\x0eNormalizedType\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\n\n\x06STRING\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\r\n\tTIMESTAMP\x10\x07\"\x8e\x01\n\x11TableIndexingInfo\x12\x14\n\x0cisPrimaryKey\x18\x01 \x01(\x08\x12\x14\n\x0cisForeignKey\x18\x02 \x01(\x08\x12\x37\n\x12referencedColumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12\x14\n\x0cisOtherIndex\x18\x04 \x01(\x08\"\xe7\x01\n\x06\x43olumn\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12+\n\x04type\x18\x03 \x01(\x0b\x32\x1d.rdbms.mde_objects.ColumnType\x12\x10\n\x08position\x18\x04 \x01(\x05\x12\x12\n\nisNullable\x18\x05 \x01(\x08\x12\x37\n\tindexInfo\x18\x06 \x01(\x0b\x32$.rdbms.mde_objects.TableIndexingInfo\x12\x11\n\tisDeleted\x18\x07 \x01(\x08\"s\n\x08\x46unction\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.rdbms.mde_objects.FunctionId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12\x12\n\nsignatures\x18\x03 \x03(\t\x12\x11\n\tisDeleted\x18\x04 \x01(\x08\"<\n\x0bSchemaApiId\x12-\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\"j\n\nTableApiId\x12+\n\x07tableId\x18\x01 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12/\n\ttableType\x18\x02 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\"m\n\x0b\x43olumnApiId\x12-\n\x08\x63olumnId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12/\n\ttableType\x18\x02 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType*N\n\x05Otype\x12\x14\n\x10\x44\x41TABASE_CATALOG\x10\x00\x12\n\n\x06SCHEMA\x10\x01\x12\t\n\x05TABLE\x10\x02\x12\n\n\x06\x43OLUMN\x10\x03\x12\x0c\n\x08\x46UNCTION\x10\x04\x42\x42\n\x1a\x61lation.sdk.rdbms.grpc.mdeB\x0fMetadataObjectsP\x01Z\x11rdbms/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.mdeB\017MetadataObjectsP\001Z\021rdbms/mde_objects'
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._options = None
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_OTYPE']._serialized_start=2741
  _globals['_OTYPE']._serialized_end=2819
  _globals['_NAME']._serialized_start=46
  _globals['_NAME']._serialized_end=90
  _globals['_DATABASECATALOGID']._serialized_start=92
  _globals['_DATABASECATALOGID']._serialized_end=150
  _globals['_SCHEMAID']._serialized_start=152
  _globals['_SCHEMAID']._serialized_end=251
  _globals['_TABLEID']._serialized_start=254
  _globals['_TABLEID']._serialized_end=393
  _globals['_COLUMNID']._serialized_start=396
  _globals['_COLUMNID']._serialized_end=576
  _globals['_FUNCTIONID']._serialized_start=579
  _globals['_FUNCTIONID']._serialized_end=721
  _globals['_DATABASECATALOG']._serialized_start=723
  _globals['_DATABASECATALOG']._serialized_end=813
  _globals['_SCHEMA']._serialized_start=815
  _globals['_SCHEMA']._serialized_end=906
  _globals['_TABLETYPE']._serialized_start=909
  _globals['_TABLETYPE']._serialized_end=1051
  _globals['_TABLETYPE_NORMALIZEDTYPE']._serialized_start=1001
  _globals['_TABLETYPE_NORMALIZEDTYPE']._serialized_end=1051
  _globals['_PARTITION']._serialized_start=1053
  _globals['_PARTITION']._serialized_end=1130
  _globals['_FILESYSTEMPATH']._serialized_start=1132
  _globals['_FILESYSTEMPATH']._serialized_end=1166
  _globals['_DATALOCATION']._serialized_start=1168
  _globals['_DATALOCATION']._serialized_end=1283
  _globals['_TABLE']._serialized_start=1286
  _globals['_TABLE']._serialized_end=1741
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_start=1682
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_end=1741
  _globals['_COLUMNTYPE']._serialized_start=1744
  _globals['_COLUMNTYPE']._serialized_end=1962
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_start=1858
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_end=1962
  _globals['_TABLEINDEXINGINFO']._serialized_start=1965
  _globals['_TABLEINDEXINGINFO']._serialized_end=2107
  _globals['_COLUMN']._serialized_start=2110
  _globals['_COLUMN']._serialized_end=2341
  _globals['_FUNCTION']._serialized_start=2343
  _globals['_FUNCTION']._serialized_end=2458
  _globals['_SCHEMAAPIID']._serialized_start=2460
  _globals['_SCHEMAAPIID']._serialized_end=2520
  _globals['_TABLEAPIID']._serialized_start=2522
  _globals['_TABLEAPIID']._serialized_end=2628
  _globals['_COLUMNAPIID']._serialized_start=2630
  _globals['_COLUMNAPIID']._serialized_end=2739
# @@protoc_insertion_point(module_scope)



from typing import Iterator, Optional
from queryservice_client.protobuf.rdbms.query_pb2 import QueryResponse, QueryResultObject
from queryservice_client.stream.immutablelist import ImmutableList
from queryservice_client.stream.reconnect import Reconnect
from queryservice_client.stream.cancelled import Cancelled

class Stream:
    def __init__(self, stream: Iterator[QueryResponse]):
        self.stream = stream
        self.buffer = ImmutableList()
        self._peek: Optional[QueryResultObject] = None

    def has_next(self) -> bool:
        is_next = self._peek is not None or not self.buffer.is_empty()
        if not is_next:
            try:
                next(self.stream)
                is_next = True
            except StopIteration:
                return False
        return is_next

    def __next__(self) -> QueryResultObject:
        if self._peek is not None:
            next_obj = self._peek
            self._peek = None
            return next_obj
        elif not self.buffer.is_empty():
            return self.buffer.pop()
        else:
            while True:
                result = next(self.stream)
                if result.cancelled:
                    raise Cancelled()
                if result.restart:
                    raise Reconnect()
                objects = result.queryResult.objects
                if not objects:
                    continue
                self.buffer.set(objects)
                return self.buffer.pop()

    def peek(self) -> QueryResultObject:
        if self._peek is not None:
            return self._peek
        try:
            self._peek = next(self)
        except StopIteration:
            return None
        return self._peek


from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Otype(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FILE: _ClassVar[Otype]
    BOOKMARK: _ClassVar[Otype]
    COLUMN: _ClassVar[Otype]
FILE: Otype
BOOKMARK: Otype
COLUMN: Otype

class Path(_message.Message):
    __slots__ = ("filePath",)
    FILEPATH_FIELD_NUMBER: _ClassVar[int]
    filePath: str
    def __init__(self, filePath: _Optional[str] = ...) -> None: ...

class ExtractionProgress(_message.Message):
    __slots__ = ("message", "completedOtype")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    COMPLETEDOTYPE_FIELD_NUMBER: _ClassVar[int]
    message: str
    completedOtype: Otype
    def __init__(self, message: _Optional[str] = ..., completedOtype: _Optional[_Union[Otype, str]] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ("path",)
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedCompositeFieldContainer[Path]
    def __init__(self, path: _Optional[_Iterable[_Union[Path, _Mapping]]] = ...) -> None: ...

class File(_message.Message):
    __slots__ = ("rootPath", "path", "type", "pathDelimiter", "isDirectory", "isDeleted", "owner", "sizeInBytes", "createTime", "lastModifiedTimestamp", "lastAccessedTimestamp", "group", "permission")
    ROOTPATH_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PATHDELIMITER_FIELD_NUMBER: _ClassVar[int]
    ISDIRECTORY_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    SIZEINBYTES_FIELD_NUMBER: _ClassVar[int]
    CREATETIME_FIELD_NUMBER: _ClassVar[int]
    LASTMODIFIEDTIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    LASTACCESSEDTIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    rootPath: str
    path: _containers.RepeatedScalarFieldContainer[str]
    type: str
    pathDelimiter: str
    isDirectory: bool
    isDeleted: bool
    owner: str
    sizeInBytes: int
    createTime: _timestamp_pb2.Timestamp
    lastModifiedTimestamp: _timestamp_pb2.Timestamp
    lastAccessedTimestamp: _timestamp_pb2.Timestamp
    group: str
    permission: str
    def __init__(self, rootPath: _Optional[str] = ..., path: _Optional[_Iterable[str]] = ..., type: _Optional[str] = ..., pathDelimiter: _Optional[str] = ..., isDirectory: bool = ..., isDeleted: bool = ..., owner: _Optional[str] = ..., sizeInBytes: _Optional[int] = ..., createTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., lastModifiedTimestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., lastAccessedTimestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., group: _Optional[str] = ..., permission: _Optional[str] = ...) -> None: ...

class Bookmark(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: _struct_pb2.Struct
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class ColumnId(_message.Message):
    __slots__ = ("path", "name", "isDirectory")
    PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ISDIRECTORY_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedScalarFieldContainer[str]
    name: str
    isDirectory: bool
    def __init__(self, path: _Optional[_Iterable[str]] = ..., name: _Optional[str] = ..., isDirectory: bool = ...) -> None: ...

class ColumnType(_message.Message):
    __slots__ = ("name", "remarks", "normalized")
    class NormalizedType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OTHER: _ClassVar[ColumnType.NormalizedType]
        BOOL: _ClassVar[ColumnType.NormalizedType]
        DATE: _ClassVar[ColumnType.NormalizedType]
        INT: _ClassVar[ColumnType.NormalizedType]
        FLOAT: _ClassVar[ColumnType.NormalizedType]
        STRING: _ClassVar[ColumnType.NormalizedType]
        TIME: _ClassVar[ColumnType.NormalizedType]
        TIMESTAMP: _ClassVar[ColumnType.NormalizedType]
    OTHER: ColumnType.NormalizedType
    BOOL: ColumnType.NormalizedType
    DATE: ColumnType.NormalizedType
    INT: ColumnType.NormalizedType
    FLOAT: ColumnType.NormalizedType
    STRING: ColumnType.NormalizedType
    TIME: ColumnType.NormalizedType
    TIMESTAMP: ColumnType.NormalizedType
    NAME_FIELD_NUMBER: _ClassVar[int]
    REMARKS_FIELD_NUMBER: _ClassVar[int]
    NORMALIZED_FIELD_NUMBER: _ClassVar[int]
    name: str
    remarks: str
    normalized: ColumnType.NormalizedType
    def __init__(self, name: _Optional[str] = ..., remarks: _Optional[str] = ..., normalized: _Optional[_Union[ColumnType.NormalizedType, str]] = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("id", "type", "position", "isNullable")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    ISNULLABLE_FIELD_NUMBER: _ClassVar[int]
    id: ColumnId
    type: ColumnType
    position: int
    isNullable: bool
    def __init__(self, id: _Optional[_Union[ColumnId, _Mapping]] = ..., type: _Optional[_Union[ColumnType, _Mapping]] = ..., position: _Optional[int] = ..., isNullable: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GBMBIObject(_message.Message):
    __slots__ = ("id", "name", "biObjectType", "description", "createdAt", "lastUpdated", "source_url", "biCompositeKey")
    class BiCompositeKeyEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    BIOBJECTTYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    LASTUPDATED_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    BICOMPOSITEKEY_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    biObjectType: str
    description: str
    createdAt: str
    lastUpdated: str
    source_url: str
    biCompositeKey: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., biObjectType: _Optional[str] = ..., description: _Optional[str] = ..., createdAt: _Optional[str] = ..., lastUpdated: _Optional[str] = ..., source_url: _Optional[str] = ..., biCompositeKey: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GBMBIUser(_message.Message):
    __slots__ = ("biObject", "username")
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    username: str
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., username: _Optional[str] = ...) -> None: ...

class GBMBIFolder(_message.Message):
    __slots__ = ("biObject", "owner", "numReports", "numReportAccesses", "parentFolderId", "isExtractable")
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NUMREPORTS_FIELD_NUMBER: _ClassVar[int]
    NUMREPORTACCESSES_FIELD_NUMBER: _ClassVar[int]
    PARENTFOLDERID_FIELD_NUMBER: _ClassVar[int]
    ISEXTRACTABLE_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    owner: str
    numReports: int
    numReportAccesses: int
    parentFolderId: str
    isExtractable: bool
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., owner: _Optional[str] = ..., numReports: _Optional[int] = ..., numReportAccesses: _Optional[int] = ..., parentFolderId: _Optional[str] = ..., isExtractable: bool = ...) -> None: ...

class GBMBIReport(_message.Message):
    __slots__ = ("biObject", "owner", "numAccesses", "parentFolderId", "parentReportIds", "datasourceIds", "type")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SIMPLE: _ClassVar[GBMBIReport.Type]
        DASHBOARD: _ClassVar[GBMBIReport.Type]
    SIMPLE: GBMBIReport.Type
    DASHBOARD: GBMBIReport.Type
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NUMACCESSES_FIELD_NUMBER: _ClassVar[int]
    PARENTFOLDERID_FIELD_NUMBER: _ClassVar[int]
    PARENTREPORTIDS_FIELD_NUMBER: _ClassVar[int]
    DATASOURCEIDS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    owner: str
    numAccesses: int
    parentFolderId: str
    parentReportIds: _containers.RepeatedScalarFieldContainer[str]
    datasourceIds: _containers.RepeatedScalarFieldContainer[str]
    type: GBMBIReport.Type
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., owner: _Optional[str] = ..., numAccesses: _Optional[int] = ..., parentFolderId: _Optional[str] = ..., parentReportIds: _Optional[_Iterable[str]] = ..., datasourceIds: _Optional[_Iterable[str]] = ..., type: _Optional[_Union[GBMBIReport.Type, str]] = ...) -> None: ...

class GBMBIDatasource(_message.Message):
    __slots__ = ("biObject", "owner", "parentFolderId", "connectionIds", "linkedDatasourceIds")
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PARENTFOLDERID_FIELD_NUMBER: _ClassVar[int]
    CONNECTIONIDS_FIELD_NUMBER: _ClassVar[int]
    LINKEDDATASOURCEIDS_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    owner: str
    parentFolderId: str
    connectionIds: _containers.RepeatedScalarFieldContainer[str]
    linkedDatasourceIds: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., owner: _Optional[str] = ..., parentFolderId: _Optional[str] = ..., connectionIds: _Optional[_Iterable[str]] = ..., linkedDatasourceIds: _Optional[_Iterable[str]] = ...) -> None: ...

class GBMBIConnection(_message.Message):
    __slots__ = ("biObject", "parentFolderId", "connectionType", "displayConnectionType", "databaseType", "host", "port", "dbSchema", "dbTable", "sql", "dataFiles")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FILES: _ClassVar[GBMBIConnection.Type]
        TABLE: _ClassVar[GBMBIConnection.Type]
        SQL_QUERY: _ClassVar[GBMBIConnection.Type]
        OTHER: _ClassVar[GBMBIConnection.Type]
    FILES: GBMBIConnection.Type
    TABLE: GBMBIConnection.Type
    SQL_QUERY: GBMBIConnection.Type
    OTHER: GBMBIConnection.Type
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    PARENTFOLDERID_FIELD_NUMBER: _ClassVar[int]
    CONNECTIONTYPE_FIELD_NUMBER: _ClassVar[int]
    DISPLAYCONNECTIONTYPE_FIELD_NUMBER: _ClassVar[int]
    DATABASETYPE_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    DBSCHEMA_FIELD_NUMBER: _ClassVar[int]
    DBTABLE_FIELD_NUMBER: _ClassVar[int]
    SQL_FIELD_NUMBER: _ClassVar[int]
    DATAFILES_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    parentFolderId: str
    connectionType: GBMBIConnection.Type
    displayConnectionType: str
    databaseType: str
    host: str
    port: str
    dbSchema: str
    dbTable: str
    sql: str
    dataFiles: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., parentFolderId: _Optional[str] = ..., connectionType: _Optional[_Union[GBMBIConnection.Type, str]] = ..., displayConnectionType: _Optional[str] = ..., databaseType: _Optional[str] = ..., host: _Optional[str] = ..., port: _Optional[str] = ..., dbSchema: _Optional[str] = ..., dbTable: _Optional[str] = ..., sql: _Optional[str] = ..., dataFiles: _Optional[_Iterable[str]] = ...) -> None: ...

class GBMBIColumnBase(_message.Message):
    __slots__ = ("biObject", "dataType", "role", "expression", "values")
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    DATATYPE_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    biObject: GBMBIObject
    dataType: str
    role: str
    expression: str
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, biObject: _Optional[_Union[GBMBIObject, _Mapping]] = ..., dataType: _Optional[str] = ..., role: _Optional[str] = ..., expression: _Optional[str] = ..., values: _Optional[_Iterable[str]] = ...) -> None: ...

class GBMBIReportColumn(_message.Message):
    __slots__ = ("biColumnBase", "reportId", "datasourceColumnIds", "parentReportColumnIds")
    BICOLUMNBASE_FIELD_NUMBER: _ClassVar[int]
    REPORTID_FIELD_NUMBER: _ClassVar[int]
    DATASOURCECOLUMNIDS_FIELD_NUMBER: _ClassVar[int]
    PARENTREPORTCOLUMNIDS_FIELD_NUMBER: _ClassVar[int]
    biColumnBase: GBMBIColumnBase
    reportId: str
    datasourceColumnIds: _containers.RepeatedScalarFieldContainer[str]
    parentReportColumnIds: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, biColumnBase: _Optional[_Union[GBMBIColumnBase, _Mapping]] = ..., reportId: _Optional[str] = ..., datasourceColumnIds: _Optional[_Iterable[str]] = ..., parentReportColumnIds: _Optional[_Iterable[str]] = ...) -> None: ...

class GBMBIDatasourceColumn(_message.Message):
    __slots__ = ("biColumnBase", "datasourceId", "parentDatasourceColumnIds", "parentConnectionColumnIds")
    BICOLUMNBASE_FIELD_NUMBER: _ClassVar[int]
    DATASOURCEID_FIELD_NUMBER: _ClassVar[int]
    PARENTDATASOURCECOLUMNIDS_FIELD_NUMBER: _ClassVar[int]
    PARENTCONNECTIONCOLUMNIDS_FIELD_NUMBER: _ClassVar[int]
    biColumnBase: GBMBIColumnBase
    datasourceId: str
    parentDatasourceColumnIds: _containers.RepeatedScalarFieldContainer[str]
    parentConnectionColumnIds: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, biColumnBase: _Optional[_Union[GBMBIColumnBase, _Mapping]] = ..., datasourceId: _Optional[str] = ..., parentDatasourceColumnIds: _Optional[_Iterable[str]] = ..., parentConnectionColumnIds: _Optional[_Iterable[str]] = ...) -> None: ...

class GBMBIConnectionColumn(_message.Message):
    __slots__ = ("biColumnBase", "connectionId")
    BICOLUMNBASE_FIELD_NUMBER: _ClassVar[int]
    CONNECTIONID_FIELD_NUMBER: _ClassVar[int]
    biColumnBase: GBMBIColumnBase
    connectionId: str
    def __init__(self, biColumnBase: _Optional[_Union[GBMBIColumnBase, _Mapping]] = ..., connectionId: _Optional[str] = ...) -> None: ...

class GBMBIPermission(_message.Message):
    __slots__ = ("userExternalId", "objectOType", "objectExternalId", "id")
    USEREXTERNALID_FIELD_NUMBER: _ClassVar[int]
    OBJECTOTYPE_FIELD_NUMBER: _ClassVar[int]
    OBJECTEXTERNALID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    userExternalId: str
    objectOType: str
    objectExternalId: str
    id: str
    def __init__(self, userExternalId: _Optional[str] = ..., objectOType: _Optional[str] = ..., objectExternalId: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GBMBIImage(_message.Message):
    __slots__ = ("imageName", "imageData", "errorMessage", "hasMore")
    IMAGENAME_FIELD_NUMBER: _ClassVar[int]
    IMAGEDATA_FIELD_NUMBER: _ClassVar[int]
    ERRORMESSAGE_FIELD_NUMBER: _ClassVar[int]
    HASMORE_FIELD_NUMBER: _ClassVar[int]
    imageName: str
    imageData: bytes
    errorMessage: str
    hasMore: bool
    def __init__(self, imageName: _Optional[str] = ..., imageData: _Optional[bytes] = ..., errorMessage: _Optional[str] = ..., hasMore: bool = ...) -> None: ...

class AlationUser(_message.Message):
    __slots__ = ("username",)
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    username: str
    def __init__(self, username: _Optional[str] = ...) -> None: ...



from typing import Iterator
from queryservice_client.stream.segments.metadata import Metadata
from queryservice_client.stream.resultsetstream import ResultSetStream
from queryservice_client.stream.segments.row import Row
from queryservice_client.stream.rowstream import RowStream
from queryservice_client.stream.types.all_data_type import Data
from queryservice_client.stream.metadatastream import MetadataStream

class ResultSet(Iterator[Row]):
    def __init__(self, stream: ResultSetStream):
        self.stream = stream
        self.update_count = -1
        self.metadata = Metadata()
        self.eager_init()

    def eager_init(self):
        md = MetadataStream(self.stream)
        for metadata in md:
            if metadata.projection is not None:
                self.metadata.add(metadata.projection)
            else:
                self.update_count = metadata.updateCount

    def get_metadata(self):
        return self.metadata

    def get_update_count(self):
        return self.update_count

    def __iter__(self):
        return self

    def __next__(self):
        stream = False
        row = Row()
        for data in RowStream(self.stream):
            row.append(Data.create(data))
            stream = True
        if not stream:
            raise StopIteration
        return row

    def has_next(self):
        return self.stream.has_next()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/qle.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0frdbms/qle.proto\x12\trdbms.qle\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1a\x63ommon/configuration.proto\"v\n\x07Request\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x35\n\x10runConfiguration\x18\x02 \x01(\x0b\x32\x1b.rdbms.qle.RunConfiguration\"}\n\x10RunConfiguration\x12\r\n\x05limit\x18\x01 \x01(\x04\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x82\x01\n\x08Response\x12.\n\tstatement\x18\x01 \x01(\x0b\x32\x19.rdbms.qle.QueryStatementH\x00\x12(\n\x06result\x18\x02 \x01(\x0b\x32\x16.rdbms.qle.FinalResultH\x00\x12\x10\n\x08isResult\x18\x03 \x01(\x08\x42\n\n\x08response\"\xa0\x01\n\x0b\x46inalResult\x12\x16\n\x0estatementCount\x18\x01 \x01(\x04\x12\x36\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32$.rdbms.qle.FinalResult.AccountsEntry\x12\x10\n\x08warnings\x18\x03 \x03(\t\x1a/\n\rAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x85\x02\n\x0eQueryStatement\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65\x66\x61ultDatabases\x18\x03 \x01(\t\x12\x11\n\tsessionId\x18\x04 \x01(\t\x12\x34\n\x10sessionStartTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tstartTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tcancelled\x18\x07 \x01(\x08\x12\x14\n\x0csecondsTaken\x18\x08 \x01(\x02\x12\x18\n\x10\x64\x65stinationTable\x18\t \x01(\tB=\n\x1a\x61lation.sdk.rdbms.grpc.qleB\x12QueryLogExtractionP\x01Z\trdbms/qleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.qle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.qleB\022QueryLogExtractionP\001Z\trdbms/qle'
  _globals['_FINALRESULT_ACCOUNTSENTRY']._options = None
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_REQUEST']._serialized_start=91
  _globals['_REQUEST']._serialized_end=209
  _globals['_RUNCONFIGURATION']._serialized_start=211
  _globals['_RUNCONFIGURATION']._serialized_end=336
  _globals['_RESPONSE']._serialized_start=339
  _globals['_RESPONSE']._serialized_end=469
  _globals['_FINALRESULT']._serialized_start=472
  _globals['_FINALRESULT']._serialized_end=632
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_start=585
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_end=632
  _globals['_QUERYSTATEMENT']._serialized_start=635
  _globals['_QUERYSTATEMENT']._serialized_end=896
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/volume_check.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66s/volume_check.proto\x12\x0f\x66s.volume_check\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\"\xf6\x01\n\x12VolumeCheckRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x43\n\x08rootInfo\x18\x02 \x03(\x0b\x32\x31.fs.volume_check.VolumeCheckRequest.RootInfoEntry\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x1aJ\n\rRootInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.fs.volume_check.RootInfo:\x02\x38\x01\"5\n\x08RootInfo\x12\x12\n\ntsSnapshot\x18\x01 \x01(\x03\x12\x15\n\rcurrentVolume\x18\x02 \x01(\x03\"~\n\x13VolumeCheckResponse\x12-\n\x04item\x18\x01 \x01(\x0b\x32\x1d.fs.volume_check.ResponseItemH\x00\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x15\n\x13VolumeCheckResponse\"]\n\x0cResponseItem\x12\x10\n\x08rootName\x18\x01 \x01(\t\x12\'\n\x06volume\x18\x02 \x01(\x0b\x32\x17.fs.volume_check.Volume\x12\x12\n\ntsSnapshot\x18\x03 \x01(\x03\"3\n\x06Volume\x12\x11\n\tfileCount\x18\x01 \x01(\x03\x12\x16\n\x0e\x64irectoryCount\x18\x02 \x01(\x03\x42\x42\n alation.sdk.fs.grpc.volume_checkB\x0bVolumeCheckP\x01Z\x0f\x66s/volume_checkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.volume_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n alation.sdk.fs.grpc.volume_checkB\013VolumeCheckP\001Z\017fs/volume_check'
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._options = None
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_options = b'8\001'
  _globals['_VOLUMECHECKREQUEST']._serialized_start=95
  _globals['_VOLUMECHECKREQUEST']._serialized_end=341
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_start=267
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_end=341
  _globals['_ROOTINFO']._serialized_start=343
  _globals['_ROOTINFO']._serialized_end=396
  _globals['_VOLUMECHECKRESPONSE']._serialized_start=398
  _globals['_VOLUMECHECKRESPONSE']._serialized_end=524
  _globals['_RESPONSEITEM']._serialized_start=526
  _globals['_RESPONSEITEM']._serialized_end=619
  _globals['_VOLUME']._serialized_start=621
  _globals['_VOLUME']._serialized_end=672
# @@protoc_insertion_point(module_scope)



import os
import base64
from typing import Optional, Union
from google.protobuf.message import DecodeError
from grpc import Channel, insecure_channel, intercept_channel
from queryservice_client.protobuf.common.configuration_pb2 import ProtobufConfiguration
from queryservice_client.protobuf.common.auth_pb2 import Auth
from queryservice_client.protobuf.rdbms.rdbms_pb2_grpc import RdbmsStub
from queryservice_client.protobuf.rdbms.query_pb2 import (
    StartSessionRequest,
    QueryRequest,
    CancelQueryRequest,
    EndSessionRequest,
)
from queryservice_client.protobuf.servicediscovery.servicediscovery_pb2 import Agent
from queryservice_client.protobuf.servicediscovery.servicediscovery_pb2_grpc import (
    ProxyServiceDiscoveryStub,
)
from queryservice_client.stream.segments.statement import Statement
from queryservice_client.stream.stream import Stream
from queryservice_client.header_manipulator_client_interceptor import header_adder_interceptor
from future.utils import native


class QueryClient:
    DEFAULT_MAX_INBOUND_IN_BYTES = 1024 * 1024 * 64  # 64MiB

    def __init__(self, channel: Channel):
        self.channel = channel
        self.inner = RdbmsStub(self.channel)

    @classmethod
    def from_connector_id(
        cls,
        connector_id: int,
        max_inbound_message_size: int = DEFAULT_MAX_INBOUND_IN_BYTES,
    ):
        host = os.environ.get("CONNECTOR_HOST", "localhost")
        return cls.from_target(
            f"{host}:{10000 + connector_id}", max_inbound_message_size
        )

    @classmethod
    def from_target(
        cls, target: str, max_inbound_message_size: int = DEFAULT_MAX_INBOUND_IN_BYTES
    ):
        return cls(
            cls.resolve(
                target=target, max_inbound_message_size=max_inbound_message_size
            )
        )

    @classmethod
    def from_agent(
        cls,
        connector_id: int,
        agent_id: str,
        max_inbound_message_size: int = DEFAULT_MAX_INBOUND_IN_BYTES,
    ):
        channel = cls.resolve(
            agent_id=agent_id, max_inbound_message_size=max_inbound_message_size
        )
        headers = cls.headers(connector_id, agent_id)
        interceptor = header_adder_interceptor(headers)
        channel = intercept_channel(channel, interceptor)
        return cls(channel)

    def new_session(
        self, configuration: ProtobufConfiguration, auth: Optional[Auth] = None
    ):
        from queryservice_client.querysession import QuerySession

        request = StartSessionRequest(configuration=configuration, authentication=auth)
        response = self.inner.StartSession(request)
        return QuerySession(response.sessionId, self)

    def new_session_from_b64(
        self, b64_encoded_configuration: str, b64_encoded_auth: Optional[str] = None
    ):
        configuration = self.configuration_from_b64_string(b64_encoded_configuration)
        auth = (
            self.auth_configuration_from_b64_string(b64_encoded_auth)
            if b64_encoded_auth
            else None
        )
        return self.new_session(configuration, auth)

    def reuse_session(self, session_id: int):
        from queryservice_client.querysession import QuerySession

        return QuerySession(session_id, self)

    def query(
        self,
        session_id: int,
        query: str,
        limit: Optional[int] = None,
        timeout_in_seconds: Optional[int] = None,
    ) -> None:
        request = QueryRequest(
            sessionId=session_id, query=query, limit=limit, timeout=timeout_in_seconds
        )
        return Statement(
            Stream(self.inner.Query(request)),
            lambda: self.cancel_query(session_id),
        )

    def cancel_query(self, session_id: int) -> None:
        request = CancelQueryRequest(sessionId=session_id)
        self.inner.CancelQuery(request)

    def end_session(self, session_id: int) -> None:
        request = EndSessionRequest(sessionId=session_id)
        self.inner.EndSession(request)

    @staticmethod
    def resolve(
        agent_id: Optional[str] = None,
        target: Optional[str] = None,
        max_inbound_message_size: int = DEFAULT_MAX_INBOUND_IN_BYTES,
    ) -> Channel:
        if agent_id:
            return QueryClient.resolve_agent(agent_id)
        return insecure_channel(
            target,
            options=[("grpc.max_receive_message_length", max_inbound_message_size)],
        )

    @staticmethod
    def resolve_agent(
        agent_id: str, max_inbound_message_size: int = DEFAULT_MAX_INBOUND_IN_BYTES
    ) -> Channel:
        channel = insecure_channel("servicediscovery.ocf-system:80")
        try:
            target = (
                ProxyServiceDiscoveryStub(channel)
                .ResolveProxiesFor(Agent(uuid=agent_id))
                .proxies[0]
            )
            return insecure_channel(
                target,
                options=[("grpc.max_receive_message_length", max_inbound_message_size)],
            )
        finally:
            channel.close()

    @staticmethod
    def headers(connector_id: int, agent_id: str) -> dict:
        return {"x-alation-agent": native(str(agent_id)), "x-alation-connector": native(str(connector_id))}

    @staticmethod
    def configuration_from_b64_string(b64_string: str) -> ProtobufConfiguration:
        try:
            return ProtobufConfiguration.FromString(base64.b64decode(b64_string))
        except DecodeError as e:
            raise ValueError("Invalid base64 configuration string") from e

    @staticmethod
    def auth_configuration_from_b64_string(b64_string: str) -> Auth:
        try:
            return Auth.FromString(base64.b64decode(b64_string))
        except DecodeError as e:
            raise ValueError("Invalid base64 auth string") from e

    def close(self) -> None:
        self.channel.close()

    @staticmethod
    def resolve_client(connector_metadata: dict[str, Union[int, str]]) -> "QueryClient":
        connector_id: int = connector_metadata.get("connector_id")
        agent_id: str = connector_metadata.get("agent_id")
        use_dev_deployment_address = os.environ.get("USE_DEV_DEPLOYMENT_ADDRESS", "false").lower() == "true"
        if use_dev_deployment_address:
            deployment_address = None
        else:
            deployment_address: str = connector_metadata.get("deployment_address")
        if agent_id != None:
            return QueryClient.from_agent(connector_id, agent_id)
        elif deployment_address != None:
            return QueryClient.from_target(deployment_address)
        return QueryClient.from_connector_id(connector_id)


def run_query(connector_metadata: dict[str, Union[int, str]], query: str, logger: any) -> (list, list):
    rows = []
    columns = None
    try:
        logger.debug("Connector metadata: ")
        for key, value in connector_metadata.items():
            if key != "protobuf_config":
                logger.debug(f"{key}: {value}")

        logger.info(f"Running query: \n {query}")
        client = QueryClient.resolve_client(connector_metadata)
        protobuf_config_str: str = connector_metadata.get("protobuf_config")
        session = client.new_session_from_b64(protobuf_config_str)
        statement = session.query(query, timeout_in_seconds=600)  # 10 minutes timeout
        logger.info("Query execution completed.")       
        for result in statement:
            try:
                columns = result.get_metadata().get_columns_name()
                while True:
                    rowstream = next(result)
                    row = []
                    for w in rowstream:
                        row.append(w.get())
                    if row:
                        rows.append(row)
            except StopIteration:
                logger.info("Completed reading results.")
        session.close()
    except Exception as e:
        logger.error(f"Query execution failed with exception: {e}")
        logger.error(f"Failed query: \n {query}")
        raise
    finally:
        client.close()
    return columns, rows



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Auth(_message.Message):
    __slots__ = ("none", "simple", "oauth", "oauthRefresh", "awsBasic", "awsSession", "azureBasic", "refreshToken")
    NONE_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_FIELD_NUMBER: _ClassVar[int]
    OAUTH_FIELD_NUMBER: _ClassVar[int]
    OAUTHREFRESH_FIELD_NUMBER: _ClassVar[int]
    AWSBASIC_FIELD_NUMBER: _ClassVar[int]
    AWSSESSION_FIELD_NUMBER: _ClassVar[int]
    AZUREBASIC_FIELD_NUMBER: _ClassVar[int]
    REFRESHTOKEN_FIELD_NUMBER: _ClassVar[int]
    none: _empty_pb2.Empty
    simple: Simple
    oauth: OAuth
    oauthRefresh: OAuthRefresh
    awsBasic: AwsBasic
    awsSession: AwsSession
    azureBasic: AzureBasic
    refreshToken: CAGRequest
    def __init__(self, none: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., simple: _Optional[_Union[Simple, _Mapping]] = ..., oauth: _Optional[_Union[OAuth, _Mapping]] = ..., oauthRefresh: _Optional[_Union[OAuthRefresh, _Mapping]] = ..., awsBasic: _Optional[_Union[AwsBasic, _Mapping]] = ..., awsSession: _Optional[_Union[AwsSession, _Mapping]] = ..., azureBasic: _Optional[_Union[AzureBasic, _Mapping]] = ..., refreshToken: _Optional[_Union[CAGRequest, _Mapping]] = ...) -> None: ...

class Simple(_message.Message):
    __slots__ = ("username", "password")
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    username: str
    password: str
    def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class OAuth(_message.Message):
    __slots__ = ("accessToken", "expiresIn", "expiry", "uri")
    ACCESSTOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRESIN_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    accessToken: str
    expiresIn: int
    expiry: int
    uri: str
    def __init__(self, accessToken: _Optional[str] = ..., expiresIn: _Optional[int] = ..., expiry: _Optional[int] = ..., uri: _Optional[str] = ...) -> None: ...

class OAuthRefresh(_message.Message):
    __slots__ = ("refreshToken", "clientId", "clientSecret")
    REFRESHTOKEN_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTSECRET_FIELD_NUMBER: _ClassVar[int]
    refreshToken: str
    clientId: str
    clientSecret: str
    def __init__(self, refreshToken: _Optional[str] = ..., clientId: _Optional[str] = ..., clientSecret: _Optional[str] = ...) -> None: ...

class AwsBasic(_message.Message):
    __slots__ = ("accessKey", "secretKey")
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    SECRETKEY_FIELD_NUMBER: _ClassVar[int]
    accessKey: str
    secretKey: str
    def __init__(self, accessKey: _Optional[str] = ..., secretKey: _Optional[str] = ...) -> None: ...

class AwsSession(_message.Message):
    __slots__ = ("accessKey", "secretKey", "sessionToken", "dbUserName", "expiry")
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    SECRETKEY_FIELD_NUMBER: _ClassVar[int]
    SESSIONTOKEN_FIELD_NUMBER: _ClassVar[int]
    DBUSERNAME_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    accessKey: str
    secretKey: str
    sessionToken: str
    dbUserName: str
    expiry: int
    def __init__(self, accessKey: _Optional[str] = ..., secretKey: _Optional[str] = ..., sessionToken: _Optional[str] = ..., dbUserName: _Optional[str] = ..., expiry: _Optional[int] = ...) -> None: ...

class AzureBasic(_message.Message):
    __slots__ = ("isSAS", "accessKey")
    ISSAS_FIELD_NUMBER: _ClassVar[int]
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    isSAS: bool
    accessKey: str
    def __init__(self, isSAS: bool = ..., accessKey: _Optional[str] = ...) -> None: ...

class CAGRequest(_message.Message):
    __slots__ = ("hostname", "token", "eagerInitialize")
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    EAGERINITIALIZE_FIELD_NUMBER: _ClassVar[int]
    hostname: str
    token: str
    eagerInitialize: bool
    def __init__(self, hostname: _Optional[str] = ..., token: _Optional[str] = ..., eagerInitialize: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/bi.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bi import mde_pb2 as bi_dot_mde__pb2
from bi import certify_pb2 as bi_dot_certify__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x62i/bi.proto\x12\x02\x62i\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x62i/mde.proto\x1a\x10\x62i/certify.proto\x1a\x13\x63ommon/verify.proto2\xd3\x02\n\x02\x42i\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12M\n\x0eListFileSystem\x12\x1d.bi.mde.ListFileSystemRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x12S\n\x11RunFullExtraction\x12 .bi.mde.RunFullExtractionRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x12\x61\n\x16propagateCertification\x12).bi.certify.PropagateCertificationRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x42&\n\x13\x61lation.sdk.bi.grpcB\x07\x42iProtoP\x01\xa2\x02\x03GBMb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.bi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023alation.sdk.bi.grpcB\007BiProtoP\001\242\002\003GBM'
  _globals['_BI']._serialized_start=102
  _globals['_BI']._serialized_end=441
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Bookmark(_message.Message):
    __slots__ = ("checkpoints",)
    class CheckpointsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CHECKPOINTS_FIELD_NUMBER: _ClassVar[int]
    checkpoints: _containers.ScalarMap[str, str]
    def __init__(self, checkpoints: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExtractionProgressDetailGroup(_message.Message):
    __slots__ = ("message", "key", "details")
    class DetailsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    message: str
    key: str
    details: _containers.ScalarMap[str, str]
    def __init__(self, message: _Optional[str] = ..., key: _Optional[str] = ..., details: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExtractionProgressDetail(_message.Message):
    __slots__ = ("message", "key")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    message: str
    key: str
    def __init__(self, message: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class ExtractionProgress(_message.Message):
    __slots__ = ("message", "extraction_message", "progress_details")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    EXTRACTION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_DETAILS_FIELD_NUMBER: _ClassVar[int]
    message: str
    extraction_message: ExtractionProgressDetail
    progress_details: ExtractionProgressDetailGroup
    def __init__(self, message: _Optional[str] = ..., extraction_message: _Optional[_Union[ExtractionProgressDetail, _Mapping]] = ..., progress_details: _Optional[_Union[ExtractionProgressDetailGroup, _Mapping]] = ...) -> None: ...

class KeyedBookmark(_message.Message):
    __slots__ = ("key", "value")
    class ValueEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: _containers.ScalarMap[str, str]
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/cag.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ommon/cag.proto\x12\x03\x63\x61g\"\x1b\n\nCAGRequest\x12\r\n\x05token\x18\x01 \x01(\t\"b\n\x0b\x43\x41GResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x11\n\tprotoName\x18\x04 \x01(\t\x12\x10\n\x08protoObj\x18\x05 \x01(\x0c\x32;\n\x03\x43\x41G\x12\x34\n\rRemoteRequest\x12\x0f.cag.CAGRequest\x1a\x10.cag.CAGResponse\"\x00\x42H\n\x1b\x61lation.sdk.grpc.common.cagB\x1b\x43onnectorApplicationGatewayP\x01Z\ncommon/cagb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.cag_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.grpc.common.cagB\033ConnectorApplicationGatewayP\001Z\ncommon/cag'
  _globals['_CAGREQUEST']._serialized_start=25
  _globals['_CAGREQUEST']._serialized_end=52
  _globals['_CAGRESPONSE']._serialized_start=54
  _globals['_CAGRESPONSE']._serialized_end=152
  _globals['_CAG']._serialized_start=154
  _globals['_CAG']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/filter_extraction.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from asset import filter_extraction_objects_pb2 as asset_dot_filter__extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61sset/filter_extraction.proto\x12\x1bocf.asset.filter_extraction\x1a\x1a\x63ommon/configuration.proto\x1a%asset/filter_extraction_objects.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"u\n\x18\x46ilterExtractionResponse\x12=\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.ocf.asset.filter_extraction_objects.FilterH\x00\x42\x1a\n\x18\x46ilterExtractionResponse2\x98\x01\n\x10\x46ilterExtraction\x12\x83\x01\n\x10\x46ilterExtraction\x12\x34.ocf.asset.filter_extraction.FilterExtractionRequest\x1a\x35.ocf.asset.filter_extraction.FilterExtractionResponse\"\x00\x30\x01\x42\x45\n(alation.sdk.asset.grpc.filter_extractionP\x01Z\x17\x61sset/filter_extractionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.filter_extraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(alation.sdk.asset.grpc.filter_extractionP\001Z\027asset/filter_extraction'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=129
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=208
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=210
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=327
  _globals['_FILTEREXTRACTION']._serialized_start=330
  _globals['_FILTEREXTRACTION']._serialized_end=482
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from bi import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PropagateCertificationRequest(_message.Message):
    __slots__ = ("configuration", "biObject", "note", "certify")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    BIOBJECT_FIELD_NUMBER: _ClassVar[int]
    NOTE_FIELD_NUMBER: _ClassVar[int]
    CERTIFY_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    biObject: _mde_objects_pb2.GBMBIObject
    note: str
    certify: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., biObject: _Optional[_Union[_mde_objects_pb2.GBMBIObject, _Mapping]] = ..., note: _Optional[str] = ..., certify: bool = ...) -> None: ...



import os
import yaml
from setuptools import setup, find_packages

def get_version():
    file_dir = os.path.dirname(os.path.abspath(__file__))
    changelog_file = os.path.join(file_dir, "changelog.yaml")
    version = ""
    with open(changelog_file) as f:
        parsed_changelog = yaml.safe_load(f)
        version = parsed_changelog['version']['current-version']
    # If building for public PyPI, publish clean base version
    no_build_suffix = os.getenv('NO_BUILD_SUFFIX', '').lower() in {"1", "true", "yes"}
    if no_build_suffix:
        return version

    build_number = os.getenv('BUILD_NUMBER', "0")
    return f"{version}+{build_number}"

setup(
    name='alation_queryservice_client',
    version=get_version(),
    include_package_data=True,
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        'grpcio==1.60.1',
        'grpcio-tools==1.60.1',
        'protobuf==4.25.2',
        "future==0.18.3"
    ],
    python_requires=">=3.7",
    classifiers=[
    "Programming Language :: Python :: 3",
    "Operating System :: OS Independent"
    ],
)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as _extraction_objects_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FilterExtractionRequest(_message.Message):
    __slots__ = ("configuration",)
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ...) -> None: ...

class FilterExtractionResponse(_message.Message):
    __slots__ = ("databaseCatalogId", "schemaId", "tableId", "error")
    DATABASECATALOGID_FIELD_NUMBER: _ClassVar[int]
    SCHEMAID_FIELD_NUMBER: _ClassVar[int]
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    databaseCatalogId: _mde_objects_pb2.DatabaseCatalogId
    schemaId: _mde_objects_pb2.SchemaId
    tableId: _mde_objects_pb2.TableId
    error: _job_error_pb2.Error
    def __init__(self, databaseCatalogId: _Optional[_Union[_mde_objects_pb2.DatabaseCatalogId, _Mapping]] = ..., schemaId: _Optional[_Union[_mde_objects_pb2.SchemaId, _Mapping]] = ..., tableId: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...

class MetadataExtractionRequest(_message.Message):
    __slots__ = ("configuration", "filter", "is_include_filter", "bookmark")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IS_INCLUDE_FILTER_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    filter: _containers.RepeatedCompositeFieldContainer[FilterExtractionResponse]
    is_include_filter: bool
    bookmark: _extraction_objects_pb2.Bookmark
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., filter: _Optional[_Iterable[_Union[FilterExtractionResponse, _Mapping]]] = ..., is_include_filter: bool = ..., bookmark: _Optional[_Union[_extraction_objects_pb2.Bookmark, _Mapping]] = ...) -> None: ...

class ExtractionProgress(_message.Message):
    __slots__ = ("message", "completedOtype")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    COMPLETEDOTYPE_FIELD_NUMBER: _ClassVar[int]
    message: str
    completedOtype: _mde_objects_pb2.Otype
    def __init__(self, message: _Optional[str] = ..., completedOtype: _Optional[_Union[_mde_objects_pb2.Otype, str]] = ...) -> None: ...

class MetadataExtractionResponse(_message.Message):
    __slots__ = ("databaseCatalog", "schema", "table", "column", "function", "extractionProgress", "error", "bookmark")
    DATABASECATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    databaseCatalog: _mde_objects_pb2.DatabaseCatalog
    schema: _mde_objects_pb2.Schema
    table: _mde_objects_pb2.Table
    column: _mde_objects_pb2.Column
    function: _mde_objects_pb2.Function
    extractionProgress: ExtractionProgress
    error: _job_error_pb2.Error
    bookmark: _extraction_objects_pb2.Bookmark
    def __init__(self, databaseCatalog: _Optional[_Union[_mde_objects_pb2.DatabaseCatalog, _Mapping]] = ..., schema: _Optional[_Union[_mde_objects_pb2.Schema, _Mapping]] = ..., table: _Optional[_Union[_mde_objects_pb2.Table, _Mapping]] = ..., column: _Optional[_Union[_mde_objects_pb2.Column, _Mapping]] = ..., function: _Optional[_Union[_mde_objects_pb2.Function, _Mapping]] = ..., extractionProgress: _Optional[_Union[ExtractionProgress, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ..., bookmark: _Optional[_Union[_extraction_objects_pb2.Bookmark, _Mapping]] = ...) -> None: ...

class TableExtractionRequest(_message.Message):
    __slots__ = ("configuration", "tableId", "tableType")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    TABLETYPE_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    tableId: _mde_objects_pb2.TableId
    tableType: _mde_objects_pb2.TableType
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., tableId: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ..., tableType: _Optional[_Union[_mde_objects_pb2.TableType, _Mapping]] = ...) -> None: ...

class TableExtractionResponse(_message.Message):
    __slots__ = ("table", "column")
    TABLE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    table: _mde_objects_pb2.Table
    column: _mde_objects_pb2.Column
    def __init__(self, table: _Optional[_Union[_mde_objects_pb2.Table, _Mapping]] = ..., column: _Optional[_Union[_mde_objects_pb2.Column, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Otype(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DATABASE_CATALOG: _ClassVar[Otype]
    SCHEMA: _ClassVar[Otype]
    TABLE: _ClassVar[Otype]
    COLUMN: _ClassVar[Otype]
    FUNCTION: _ClassVar[Otype]
DATABASE_CATALOG: Otype
SCHEMA: Otype
TABLE: Otype
COLUMN: Otype
FUNCTION: Otype

class Name(_message.Message):
    __slots__ = ("original", "normalized")
    ORIGINAL_FIELD_NUMBER: _ClassVar[int]
    NORMALIZED_FIELD_NUMBER: _ClassVar[int]
    original: str
    normalized: str
    def __init__(self, original: _Optional[str] = ..., normalized: _Optional[str] = ...) -> None: ...

class DatabaseCatalogId(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: Name
    def __init__(self, name: _Optional[_Union[Name, _Mapping]] = ...) -> None: ...

class SchemaId(_message.Message):
    __slots__ = ("databaseCatalog", "name")
    DATABASECATALOG_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    databaseCatalog: Name
    name: Name
    def __init__(self, databaseCatalog: _Optional[_Union[Name, _Mapping]] = ..., name: _Optional[_Union[Name, _Mapping]] = ...) -> None: ...

class TableId(_message.Message):
    __slots__ = ("databaseCatalog", "schema", "name")
    DATABASECATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    databaseCatalog: Name
    schema: Name
    name: Name
    def __init__(self, databaseCatalog: _Optional[_Union[Name, _Mapping]] = ..., schema: _Optional[_Union[Name, _Mapping]] = ..., name: _Optional[_Union[Name, _Mapping]] = ...) -> None: ...

class ColumnId(_message.Message):
    __slots__ = ("databaseCatalog", "schema", "table", "name")
    DATABASECATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    databaseCatalog: Name
    schema: Name
    table: Name
    name: Name
    def __init__(self, databaseCatalog: _Optional[_Union[Name, _Mapping]] = ..., schema: _Optional[_Union[Name, _Mapping]] = ..., table: _Optional[_Union[Name, _Mapping]] = ..., name: _Optional[_Union[Name, _Mapping]] = ...) -> None: ...

class FunctionId(_message.Message):
    __slots__ = ("databaseCatalog", "schema", "name")
    DATABASECATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    databaseCatalog: Name
    schema: Name
    name: Name
    def __init__(self, databaseCatalog: _Optional[_Union[Name, _Mapping]] = ..., schema: _Optional[_Union[Name, _Mapping]] = ..., name: _Optional[_Union[Name, _Mapping]] = ...) -> None: ...

class DatabaseCatalog(_message.Message):
    __slots__ = ("id", "sourceComment")
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCECOMMENT_FIELD_NUMBER: _ClassVar[int]
    id: DatabaseCatalogId
    sourceComment: str
    def __init__(self, id: _Optional[_Union[DatabaseCatalogId, _Mapping]] = ..., sourceComment: _Optional[str] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ("id", "sourceComment", "isDeleted")
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCECOMMENT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    id: SchemaId
    sourceComment: str
    isDeleted: bool
    def __init__(self, id: _Optional[_Union[SchemaId, _Mapping]] = ..., sourceComment: _Optional[str] = ..., isDeleted: bool = ...) -> None: ...

class TableType(_message.Message):
    __slots__ = ("name", "normalized")
    class NormalizedType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TABLE: _ClassVar[TableType.NormalizedType]
        VIEW: _ClassVar[TableType.NormalizedType]
        SYNONYM: _ClassVar[TableType.NormalizedType]
    TABLE: TableType.NormalizedType
    VIEW: TableType.NormalizedType
    SYNONYM: TableType.NormalizedType
    NAME_FIELD_NUMBER: _ClassVar[int]
    NORMALIZED_FIELD_NUMBER: _ClassVar[int]
    name: str
    normalized: TableType.NormalizedType
    def __init__(self, name: _Optional[str] = ..., normalized: _Optional[_Union[TableType.NormalizedType, str]] = ...) -> None: ...

class Partition(_message.Message):
    __slots__ = ("definition", "columns")
    DEFINITION_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    definition: str
    columns: _containers.RepeatedCompositeFieldContainer[ColumnId]
    def __init__(self, definition: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[ColumnId, _Mapping]]] = ...) -> None: ...

class FileSystemPath(_message.Message):
    __slots__ = ("segments",)
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    segments: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, segments: _Optional[_Iterable[str]] = ...) -> None: ...

class DataLocation(_message.Message):
    __slots__ = ("original", "scheme", "hostport", "path")
    ORIGINAL_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    HOSTPORT_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    original: str
    scheme: str
    hostport: str
    path: FileSystemPath
    def __init__(self, original: _Optional[str] = ..., scheme: _Optional[str] = ..., hostport: _Optional[str] = ..., path: _Optional[_Union[FileSystemPath, _Mapping]] = ...) -> None: ...

class Table(_message.Message):
    __slots__ = ("id", "sourceComment", "type", "ddl", "partition", "baseTable", "owner", "dataLocation", "additionalProperties", "isDeleted")
    class AdditionalPropertiesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCECOMMENT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DDL_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    BASETABLE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DATALOCATION_FIELD_NUMBER: _ClassVar[int]
    ADDITIONALPROPERTIES_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    id: TableId
    sourceComment: str
    type: TableType
    ddl: str
    partition: Partition
    baseTable: TableId
    owner: str
    dataLocation: DataLocation
    additionalProperties: _containers.ScalarMap[str, str]
    isDeleted: bool
    def __init__(self, id: _Optional[_Union[TableId, _Mapping]] = ..., sourceComment: _Optional[str] = ..., type: _Optional[_Union[TableType, _Mapping]] = ..., ddl: _Optional[str] = ..., partition: _Optional[_Union[Partition, _Mapping]] = ..., baseTable: _Optional[_Union[TableId, _Mapping]] = ..., owner: _Optional[str] = ..., dataLocation: _Optional[_Union[DataLocation, _Mapping]] = ..., additionalProperties: _Optional[_Mapping[str, str]] = ..., isDeleted: bool = ...) -> None: ...

class ColumnType(_message.Message):
    __slots__ = ("name", "definition", "normalized")
    class NormalizedType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OTHER: _ClassVar[ColumnType.NormalizedType]
        BOOL: _ClassVar[ColumnType.NormalizedType]
        DATE: _ClassVar[ColumnType.NormalizedType]
        INT: _ClassVar[ColumnType.NormalizedType]
        FLOAT: _ClassVar[ColumnType.NormalizedType]
        STRING: _ClassVar[ColumnType.NormalizedType]
        TIME: _ClassVar[ColumnType.NormalizedType]
        TIMESTAMP: _ClassVar[ColumnType.NormalizedType]
    OTHER: ColumnType.NormalizedType
    BOOL: ColumnType.NormalizedType
    DATE: ColumnType.NormalizedType
    INT: ColumnType.NormalizedType
    FLOAT: ColumnType.NormalizedType
    STRING: ColumnType.NormalizedType
    TIME: ColumnType.NormalizedType
    TIMESTAMP: ColumnType.NormalizedType
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEFINITION_FIELD_NUMBER: _ClassVar[int]
    NORMALIZED_FIELD_NUMBER: _ClassVar[int]
    name: str
    definition: str
    normalized: ColumnType.NormalizedType
    def __init__(self, name: _Optional[str] = ..., definition: _Optional[str] = ..., normalized: _Optional[_Union[ColumnType.NormalizedType, str]] = ...) -> None: ...

class TableIndexingInfo(_message.Message):
    __slots__ = ("isPrimaryKey", "isForeignKey", "referencedColumnId", "isOtherIndex")
    ISPRIMARYKEY_FIELD_NUMBER: _ClassVar[int]
    ISFOREIGNKEY_FIELD_NUMBER: _ClassVar[int]
    REFERENCEDCOLUMNID_FIELD_NUMBER: _ClassVar[int]
    ISOTHERINDEX_FIELD_NUMBER: _ClassVar[int]
    isPrimaryKey: bool
    isForeignKey: bool
    referencedColumnId: ColumnId
    isOtherIndex: bool
    def __init__(self, isPrimaryKey: bool = ..., isForeignKey: bool = ..., referencedColumnId: _Optional[_Union[ColumnId, _Mapping]] = ..., isOtherIndex: bool = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("id", "sourceComment", "type", "position", "isNullable", "indexInfo", "isDeleted")
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCECOMMENT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    ISNULLABLE_FIELD_NUMBER: _ClassVar[int]
    INDEXINFO_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    id: ColumnId
    sourceComment: str
    type: ColumnType
    position: int
    isNullable: bool
    indexInfo: TableIndexingInfo
    isDeleted: bool
    def __init__(self, id: _Optional[_Union[ColumnId, _Mapping]] = ..., sourceComment: _Optional[str] = ..., type: _Optional[_Union[ColumnType, _Mapping]] = ..., position: _Optional[int] = ..., isNullable: bool = ..., indexInfo: _Optional[_Union[TableIndexingInfo, _Mapping]] = ..., isDeleted: bool = ...) -> None: ...

class Function(_message.Message):
    __slots__ = ("id", "sourceComment", "signatures", "isDeleted")
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCECOMMENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    id: FunctionId
    sourceComment: str
    signatures: _containers.RepeatedScalarFieldContainer[str]
    isDeleted: bool
    def __init__(self, id: _Optional[_Union[FunctionId, _Mapping]] = ..., sourceComment: _Optional[str] = ..., signatures: _Optional[_Iterable[str]] = ..., isDeleted: bool = ...) -> None: ...

class SchemaApiId(_message.Message):
    __slots__ = ("schemaId",)
    SCHEMAID_FIELD_NUMBER: _ClassVar[int]
    schemaId: SchemaId
    def __init__(self, schemaId: _Optional[_Union[SchemaId, _Mapping]] = ...) -> None: ...

class TableApiId(_message.Message):
    __slots__ = ("tableId", "tableType")
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    TABLETYPE_FIELD_NUMBER: _ClassVar[int]
    tableId: TableId
    tableType: TableType
    def __init__(self, tableId: _Optional[_Union[TableId, _Mapping]] = ..., tableType: _Optional[_Union[TableType, _Mapping]] = ...) -> None: ...

class ColumnApiId(_message.Message):
    __slots__ = ("columnId", "tableType")
    COLUMNID_FIELD_NUMBER: _ClassVar[int]
    TABLETYPE_FIELD_NUMBER: _ClassVar[int]
    columnId: ColumnId
    tableType: TableType
    def __init__(self, columnId: _Optional[_Union[ColumnId, _Mapping]] = ..., tableType: _Optional[_Union[TableType, _Mapping]] = ...) -> None: ...



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Request(_message.Message):
    __slots__ = ("configuration", "auth", "jdbcUri")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    JDBCURI_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    auth: _auth_pb2.Auth
    jdbcUri: str
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., jdbcUri: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.rdbms import profiling_pb2 as rdbms_dot_profiling__pb2
from queryservice_client.protobuf.rdbms import qle_pb2 as rdbms_dot_qle__pb2
from queryservice_client.protobuf.rdbms import query_pb2 as rdbms_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11rdbms/rdbms.proto\x12\x05rdbms\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/verify.proto\x1a\x0frdbms/mde.proto\x1a\x15rdbms/profiling.proto\x1a\x0frdbms/qle.proto\x1a\x11rdbms/query.proto2\xa5\t\n\x05Rdbms\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12_\n\x10\x46ilterExtraction\x12\".rdbms.mde.FilterExtractionRequest\x1a#.rdbms.mde.FilterExtractionResponse\"\x00\x30\x01\x12\x65\n\x12MetadataExtraction\x12$.rdbms.mde.MetadataExtractionRequest\x1a%.rdbms.mde.MetadataExtractionResponse\"\x00\x30\x01\x12\\\n\x0fTableExtraction\x12!.rdbms.mde.TableExtractionRequest\x1a\".rdbms.mde.TableExtractionResponse\"\x00\x30\x01\x12?\n\x12QuerylogExtraction\x12\x12.rdbms.qle.Request\x1a\x13.rdbms.qle.Response0\x01\x12\x65\n\x0eTableProfiling\x12&.rdbms.profiling.TableProfilingRequest\x1a\'.rdbms.profiling.TableProfilingResponse\"\x00\x30\x01\x12h\n\x0f\x43olumnProfiling\x12\'.rdbms.profiling.ColumnProfilingRequest\x1a(.rdbms.profiling.ColumnProfilingResponse\"\x00\x30\x01\x12w\n\x14\x43ustomTableProfiling\x12,.rdbms.profiling.CustomTableProfilingRequest\x1a-.rdbms.profiling.CustomTableProfilingResponse\"\x00\x30\x01\x12t\n\x15\x43ustomColumnProfiling\x12-.rdbms.profiling.CustomColumnProfilingRequest\x1a(.rdbms.profiling.ColumnProfilingResponse\"\x00\x30\x01\x12S\n\x0cStartSession\x12 .rdbms.query.StartSessionRequest\x1a!.rdbms.query.StartSessionResponse\x12\x44\n\nEndSession\x12\x1e.rdbms.query.EndSessionRequest\x1a\x16.google.protobuf.Empty\x12@\n\x05Query\x12\x19.rdbms.query.QueryRequest\x1a\x1a.rdbms.query.QueryResponse0\x01\x12P\n\x0b\x43\x61ncelQuery\x12\x1f.rdbms.query.CancelQueryRequest\x1a .rdbms.query.CancelQueryResponseB.\n\x16\x61lation.sdk.rdbms.grpcB\nRdbmsProtoP\x01Z\x06rdbms/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026alation.sdk.rdbms.grpcB\nRdbmsProtoP\001Z\006rdbms/'
  _globals['_RDBMS']._serialized_start=155
  _globals['_RDBMS']._serialized_end=1344
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from bi import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListFileSystemRequest(_message.Message):
    __slots__ = ("configuration", "users")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    users: _containers.RepeatedCompositeFieldContainer[_mde_objects_pb2.AlationUser]
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., users: _Optional[_Iterable[_Union[_mde_objects_pb2.AlationUser, _Mapping]]] = ...) -> None: ...

class RunFullExtractionRequest(_message.Message):
    __slots__ = ("configuration", "folders", "isIncludeFilter", "users")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    FOLDERS_FIELD_NUMBER: _ClassVar[int]
    ISINCLUDEFILTER_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    folders: _containers.RepeatedCompositeFieldContainer[_mde_objects_pb2.GBMBIFolder]
    isIncludeFilter: bool
    users: _containers.RepeatedCompositeFieldContainer[_mde_objects_pb2.AlationUser]
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., folders: _Optional[_Iterable[_Union[_mde_objects_pb2.GBMBIFolder, _Mapping]]] = ..., isIncludeFilter: bool = ..., users: _Optional[_Iterable[_Union[_mde_objects_pb2.AlationUser, _Mapping]]] = ...) -> None: ...

class BIObjectResponse(_message.Message):
    __slots__ = ("biUser", "biFolder", "biReport", "biDataSource", "biConnection", "biReportColumn", "biDatasourceColumn", "biConnectionColumn", "biPermission", "biImage", "error")
    BIUSER_FIELD_NUMBER: _ClassVar[int]
    BIFOLDER_FIELD_NUMBER: _ClassVar[int]
    BIREPORT_FIELD_NUMBER: _ClassVar[int]
    BIDATASOURCE_FIELD_NUMBER: _ClassVar[int]
    BICONNECTION_FIELD_NUMBER: _ClassVar[int]
    BIREPORTCOLUMN_FIELD_NUMBER: _ClassVar[int]
    BIDATASOURCECOLUMN_FIELD_NUMBER: _ClassVar[int]
    BICONNECTIONCOLUMN_FIELD_NUMBER: _ClassVar[int]
    BIPERMISSION_FIELD_NUMBER: _ClassVar[int]
    BIIMAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    biUser: _mde_objects_pb2.GBMBIUser
    biFolder: _mde_objects_pb2.GBMBIFolder
    biReport: _mde_objects_pb2.GBMBIReport
    biDataSource: _mde_objects_pb2.GBMBIDatasource
    biConnection: _mde_objects_pb2.GBMBIConnection
    biReportColumn: _mde_objects_pb2.GBMBIReportColumn
    biDatasourceColumn: _mde_objects_pb2.GBMBIDatasourceColumn
    biConnectionColumn: _mde_objects_pb2.GBMBIConnectionColumn
    biPermission: _mde_objects_pb2.GBMBIPermission
    biImage: _mde_objects_pb2.GBMBIImage
    error: _job_error_pb2.Error
    def __init__(self, biUser: _Optional[_Union[_mde_objects_pb2.GBMBIUser, _Mapping]] = ..., biFolder: _Optional[_Union[_mde_objects_pb2.GBMBIFolder, _Mapping]] = ..., biReport: _Optional[_Union[_mde_objects_pb2.GBMBIReport, _Mapping]] = ..., biDataSource: _Optional[_Union[_mde_objects_pb2.GBMBIDatasource, _Mapping]] = ..., biConnection: _Optional[_Union[_mde_objects_pb2.GBMBIConnection, _Mapping]] = ..., biReportColumn: _Optional[_Union[_mde_objects_pb2.GBMBIReportColumn, _Mapping]] = ..., biDatasourceColumn: _Optional[_Union[_mde_objects_pb2.GBMBIDatasourceColumn, _Mapping]] = ..., biConnectionColumn: _Optional[_Union[_mde_objects_pb2.GBMBIConnectionColumn, _Mapping]] = ..., biPermission: _Optional[_Union[_mde_objects_pb2.GBMBIPermission, _Mapping]] = ..., biImage: _Optional[_Union[_mde_objects_pb2.GBMBIImage, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DQStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    GOOD: _ClassVar[DQStatus]
    WARNING: _ClassVar[DQStatus]
    ALERT: _ClassVar[DQStatus]
GOOD: DQStatus
WARNING: DQStatus
ALERT: DQStatus

class Asset(_message.Message):
    __slots__ = ("eid", "parent_eid", "properties")
    EID_FIELD_NUMBER: _ClassVar[int]
    PARENT_EID_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    eid: ExternalID
    parent_eid: ExternalID
    properties: _containers.RepeatedCompositeFieldContainer[Property]
    def __init__(self, eid: _Optional[_Union[ExternalID, _Mapping]] = ..., parent_eid: _Optional[_Union[ExternalID, _Mapping]] = ..., properties: _Optional[_Iterable[_Union[Property, _Mapping]]] = ...) -> None: ...

class ExternalID(_message.Message):
    __slots__ = ("atype_id", "atype_name", "eid")
    ATYPE_ID_FIELD_NUMBER: _ClassVar[int]
    ATYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    EID_FIELD_NUMBER: _ClassVar[int]
    atype_id: str
    atype_name: str
    eid: str
    def __init__(self, atype_id: _Optional[str] = ..., atype_name: _Optional[str] = ..., eid: _Optional[str] = ...) -> None: ...

class RelationMetadata(_message.Message):
    __slots__ = ("name", "role")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    name: str
    role: str
    def __init__(self, name: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class Property(_message.Message):
    __slots__ = ("name", "relationMetadata", "string_v", "list_v", "int32_v", "int64_v", "bool_v", "asset_v", "assets_v")
    NAME_FIELD_NUMBER: _ClassVar[int]
    RELATIONMETADATA_FIELD_NUMBER: _ClassVar[int]
    STRING_V_FIELD_NUMBER: _ClassVar[int]
    LIST_V_FIELD_NUMBER: _ClassVar[int]
    INT32_V_FIELD_NUMBER: _ClassVar[int]
    INT64_V_FIELD_NUMBER: _ClassVar[int]
    BOOL_V_FIELD_NUMBER: _ClassVar[int]
    ASSET_V_FIELD_NUMBER: _ClassVar[int]
    ASSETS_V_FIELD_NUMBER: _ClassVar[int]
    name: str
    relationMetadata: RelationMetadata
    string_v: str
    list_v: _struct_pb2.ListValue
    int32_v: int
    int64_v: int
    bool_v: bool
    asset_v: Asset
    assets_v: Assets
    def __init__(self, name: _Optional[str] = ..., relationMetadata: _Optional[_Union[RelationMetadata, _Mapping]] = ..., string_v: _Optional[str] = ..., list_v: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ..., int32_v: _Optional[int] = ..., int64_v: _Optional[int] = ..., bool_v: bool = ..., asset_v: _Optional[_Union[Asset, _Mapping]] = ..., assets_v: _Optional[_Union[Assets, _Mapping]] = ...) -> None: ...

class Assets(_message.Message):
    __slots__ = ("assets",)
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    assets: _containers.RepeatedCompositeFieldContainer[Asset]
    def __init__(self, assets: _Optional[_Iterable[_Union[Asset, _Mapping]]] = ...) -> None: ...

class DQRuleAndValue(_message.Message):
    __slots__ = ("externalID", "name", "type", "description", "asset", "status", "string_v", "int32_v", "bool_v", "url", "lastUpdatedAt")
    EXTERNALID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ASSET_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STRING_V_FIELD_NUMBER: _ClassVar[int]
    INT32_V_FIELD_NUMBER: _ClassVar[int]
    BOOL_V_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    LASTUPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    externalID: str
    name: str
    type: str
    description: str
    asset: Asset
    status: DQStatus
    string_v: str
    int32_v: int
    bool_v: bool
    url: str
    lastUpdatedAt: str
    def __init__(self, externalID: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., description: _Optional[str] = ..., asset: _Optional[_Union[Asset, _Mapping]] = ..., status: _Optional[_Union[DQStatus, str]] = ..., string_v: _Optional[str] = ..., int32_v: _Optional[int] = ..., bool_v: bool = ..., url: _Optional[str] = ..., lastUpdatedAt: _Optional[str] = ...) -> None: ...
